package cn.kdan.compdf.controller.v1;

import cn.kdan.compdf.base.R;
import cn.kdan.compdf.dto.ChangePasswordDTO;
import cn.kdan.compdf.dto.LoginDTO;
import cn.kdan.compdf.enums.AuthEnum;
import cn.kdan.compdf.service.BackgroundUserService;
import cn.kdan.compdf.utils.TokenUtil;
import cn.kdan.compdf.vo.LoginVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.Enumeration;

/**
 * @author comPDF-Kit WPH 2022-10-09
 */
@Slf4j
@RestController
@RequestMapping("/v1/user")
public class BackgroundUserController {

    private final BackgroundUserService backgroundUserService;

    public BackgroundUserController(BackgroundUserService backgroundUserService) {
        this.backgroundUserService = backgroundUserService;
    }

    /**
     * 用户登录
     */
    @PostMapping("/login")
    public R<LoginVO> login(@Validated @RequestBody LoginDTO loginDTO) {
        return backgroundUserService.login(loginDTO);
    }

    @PostMapping("/logout")
    public R<Void> logout(HttpServletRequest request) {
        String token = request.getHeader(AuthEnum.AUTHORIZATION);
        log.info("登出token：{}，time：{}", token, new Date());
        backgroundUserService.logout(token.replaceFirst("Bearer ",""));
        return R.ok();
    }

    @PutMapping("/changePassword")
    public R<Void> changePassword(@Validated @RequestBody ChangePasswordDTO changePasswordDTO, HttpServletRequest request) {
        String token = request.getHeader(AuthEnum.AUTHORIZATION);
        backgroundUserService.changePassword(changePasswordDTO, token.replaceFirst("Bearer ",""));
        return R.ok();
    }

    /**
     * userFirstLogin
     */
    @GetMapping("/userFirstLogin")
    public R<String> userFirstLogin(){
        return R.ok(backgroundUserService.getUSerFirstLogin(TokenUtil.getRequestHeader().getTenantId()).toString());
    }

}
