package cn.kdan.compdf.service.impl;

import cn.kdan.compdf.config.RedisConstantServer;
import cn.kdan.compdf.dto.TenantAssetBalanceDTO;
import cn.kdan.compdf.entity.BackgroundUserRemain;
import cn.kdan.compdf.mapper.BackgroundUserRemainMapper;
import cn.kdan.compdf.service.BackgroundUserRemainService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author ComPDFKit-WPH 2022-11-10
 */
@Service
public class BackgroundUserRemainServiceImpl extends ServiceImpl<BackgroundUserRemainMapper, BackgroundUserRemain> implements BackgroundUserRemainService {

    @Override
    public IPage<BackgroundUserRemain> page(BackgroundUserRemain query) {
        return this.page(new Page<>(query.getPage(), query.getSize()), Wrappers.query(query));
    }

    @Cacheable(value = RedisConstantServer.USER_REMAIN_TENANT, key = "#tenantId", unless = "#result == null")
    @Override
    public BackgroundUserRemain getUserRemain(Long tenantId) {
        return this.baseMapper.selectOne(new LambdaQueryWrapper<BackgroundUserRemain>()
                .eq(BackgroundUserRemain::getTenantId, tenantId));
    }

    @Override
    public void userRemainSync(List<TenantAssetBalanceDTO> tenantBalance) {
        Map<Long, List<TenantAssetBalanceDTO>> collect = tenantBalance.stream()
                .collect(Collectors.groupingBy(TenantAssetBalanceDTO::getTenantId));
        for (Long tenantId : collect.keySet()) {
            BackgroundUserRemain userRemain = this.getUserRemain(tenantId);
            Integer totalFiles = userRemain.getTotalFiles();
            int fileBalance = 0;
            for (TenantAssetBalanceDTO tenantAssetBalanceDTO : collect.get(tenantId)) {
                fileBalance += tenantAssetBalanceDTO.getAsset();
            }
            userRemain.setUsedFiles(totalFiles - fileBalance);
            this.baseMapper.update(userRemain, new LambdaQueryWrapper<BackgroundUserRemain>()
                    .eq(BackgroundUserRemain::getTenantId, tenantId));
        }
    }


}
